/***********************************************************************************************************************************
Repository Get Command
***********************************************************************************************************************************/
#ifndef COMMAND_STORAGE_GET_H
#define COMMAND_STORAGE_GET_H

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
// Get a file from the repository
FN_EXTERN int cmdStorageGet(void);

#endif
